"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.semverWorkflowPreset = void 0;
const inject_1 = require("../actions/inject");
const resolveLatestVersions_1 = require("../npm/resolveLatestVersions");
const package_1 = require("../npm/package");
const log_1 = __importDefault(require("../util/log"));
exports.semverWorkflowPreset = {
    name: 'semver-workflow',
    description: 'Files and dependencies for conventional-commits, github workflow and semantic-release.',
    apply: applyPreset,
};
const info = (write, msg, ...args) => write && log_1.default.info(msg, ...args);
function applyPreset(options) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, inject_1.writeAssets)(semverWorkflowFiles(), options);
        yield addPrepareScript(options);
        yield addDevDependencies(options);
    });
}
function addPrepareScript(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield (0, package_1.getPackage)(options);
        const didWrite = yield (0, package_1.addPackageJsonScripts)(pkg, options, (scripts) => {
            scripts.prepare = (0, package_1.addScript)(`husky install`, scripts.prepare);
            return scripts;
        });
        info(didWrite, 'Added prepare script to package.json');
    });
}
function addDevDependencies(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield (0, package_1.getPackage)(options);
        const devDeps = (0, package_1.sortKeys)(Object.assign(Object.assign({}, pkg.devDependencies), (yield semverWorkflowDependencies())));
        const newPkg = Object.assign({}, pkg);
        newPkg.devDependencies = devDeps;
        yield (0, package_1.writePackageJsonDirect)(newPkg, options);
        log_1.default.info('Updated devDependencies.');
    });
}
function semverWorkflowFiles() {
    return [
        { from: ['.github', 'workflows', 'main.yml'], to: ['.github', 'workflows', 'main.yml'] },
        { from: ['.husky', 'commit-msg'], to: ['.husky', 'commit-msg'] },
        { from: ['.husky', 'pre-commit'], to: ['.husky', 'pre-commit'] },
        { from: ['.releaserc.json'], to: '.releaserc.json' },
        { from: ['commitlint.template.js'], to: 'commitlint.config.js' },
        { from: ['lint-staged.template.js'], to: 'lint-staged.config.js' },
    ].map((fromTo) => (Object.assign(Object.assign({}, fromTo), { from: ['semver-workflow', ...fromTo.from] })));
}
function semverWorkflowDependencies() {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, resolveLatestVersions_1.resolveLatestVersions)([
            '@commitlint/cli',
            '@commitlint/config-conventional',
            '@sanity/semantic-release-preset',
            'husky',
            'lint-staged',
        ]);
    });
}
//# sourceMappingURL=semver-workflow.js.map